"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.defaultOptions = void 0;
exports.countCopies = countCopies;
exports.printModule = printModule;
exports.detectDuplicatePackages = detectDuplicatePackages;
exports.checkForDuplicateDependencies = checkForDuplicateDependencies;
exports.checkForDuplicatePackages = checkForDuplicatePackages;
const console_1 = require("@rnx-kit/console");
const gatherModules_1 = require("./gatherModules");
exports.defaultOptions = {
    ignoredModules: [],
    bannedModules: [],
    throwOnError: true,
};
function countCopies(module) {
    return Object.keys(module).reduce((count, version) => {
        return count + module[version].size;
    }, 0);
}
function printModule(module) {
    Object.keys(module)
        .sort()
        .forEach((version) => {
        Array.from(module[version])
            .sort()
            .forEach((p) => (0, console_1.warn)(`  ${version} ${p}`));
    });
}
function detectDuplicatePackages(bundledModules, { ignoredModules = [], bannedModules = [] }) {
    let numBanned = 0;
    let numDupes = 0;
    for (const name of Object.keys(bundledModules)) {
        if (bannedModules.includes(name)) {
            (0, console_1.error)(`${name} (banned)`);
            printModule(bundledModules[name]);
            numBanned += 1;
            continue;
        }
        if (ignoredModules.includes(name)) {
            continue;
        }
        const currentModule = bundledModules[name];
        const numCopies = countCopies(currentModule);
        if (numCopies > 1) {
            (0, console_1.error)(`${name} (found ${numCopies} copies)`);
            printModule(currentModule);
            numDupes += 1;
            continue;
        }
    }
    return { banned: numBanned, duplicates: numDupes };
}
function checkForDuplicateDependencies(graph, options = exports.defaultOptions) {
    return detectDuplicatePackages((0, gatherModules_1.gatherModulesFromGraph)(graph, {}), options);
}
function checkForDuplicatePackages(sourceMap, options = exports.defaultOptions) {
    return detectDuplicatePackages((0, gatherModules_1.gatherModulesFromSourceMap)(sourceMap, {}), options);
}
//# sourceMappingURL=checkForDuplicatePackages.js.map