"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkForDuplicatePackages = exports.resolveModule = exports.normalizePath = exports.detectDuplicatePackages = void 0;
exports.getErrorMessage = getErrorMessage;
exports.checkForDuplicatePackagesInFile = checkForDuplicatePackagesInFile;
exports.DuplicateDependencies = DuplicateDependencies;
const console_1 = require("@rnx-kit/console");
const fs_1 = require("fs");
const checkForDuplicatePackages_1 = require("./checkForDuplicatePackages");
Object.defineProperty(exports, "checkForDuplicatePackages", { enumerable: true, get: function () { return checkForDuplicatePackages_1.checkForDuplicatePackages; } });
var checkForDuplicatePackages_2 = require("./checkForDuplicatePackages");
Object.defineProperty(exports, "detectDuplicatePackages", { enumerable: true, get: function () { return checkForDuplicatePackages_2.detectDuplicatePackages; } });
var gatherModules_1 = require("./gatherModules");
Object.defineProperty(exports, "normalizePath", { enumerable: true, get: function () { return gatherModules_1.normalizePath; } });
Object.defineProperty(exports, "resolveModule", { enumerable: true, get: function () { return gatherModules_1.resolveModule; } });
function getErrorMessage({ banned, duplicates, }) {
    if (duplicates > 0) {
        if (banned > 0) {
            return `Found ${banned} banned module(s) and ${duplicates} duplicate(s)`;
        }
        return `Found ${duplicates} duplicate(s)`;
    }
    if (banned > 0) {
        return `Found ${banned} banned module(s)`;
    }
    return undefined;
}
function checkForDuplicatePackagesInFile(sourceMap, options = checkForDuplicatePackages_1.defaultOptions) {
    return new Promise((resolve, reject) => (0, fs_1.readFile)(sourceMap, { encoding: "utf-8" }, (e, data) => {
        if (e) {
            reject(e);
            return;
        }
        const sourceMap = JSON.parse(data);
        const result = (0, checkForDuplicatePackages_1.checkForDuplicatePackages)(sourceMap, options);
        const errorMessage = getErrorMessage(result);
        if (errorMessage) {
            const { throwOnError = true } = options;
            if (throwOnError) {
                reject(new Error(errorMessage));
            }
            else {
                (0, console_1.error)(errorMessage);
                resolve();
            }
        }
        else {
            resolve();
        }
    }));
}
function DuplicateDependencies(pluginOptions = checkForDuplicatePackages_1.defaultOptions) {
    return (_entryPoint, _preModules, graph, _options) => {
        const result = (0, checkForDuplicatePackages_1.checkForDuplicateDependencies)(graph, pluginOptions);
        const errorMessage = getErrorMessage(result);
        if (errorMessage) {
            const { throwOnError = true } = pluginOptions;
            if (throwOnError) {
                throw new Error(errorMessage);
            }
            (0, console_1.error)(errorMessage);
        }
    };
}
DuplicateDependencies.type = "serializer";
if (require.main === module) {
    checkForDuplicatePackagesInFile(process.argv[2]).catch((error) => {
        if (error) {
            process.exitCode = 1;
            error(error.message);
        }
    });
}
// `export default` required for plugin interface
// eslint-disable-next-line no-restricted-exports
exports.default = DuplicateDependencies;
//# sourceMappingURL=index.js.map